.. _api:

API
===

.. autoclass:: abgleich.Command
    :members:

.. autoclass:: abgleich.Config
    :members:

.. autoclass:: abgleich.ConfigField
    :members:

.. autoclass:: abgleich.Dataset
    :members:

.. autoclass:: abgleich.Property
    :members:

.. autoclass:: abgleich.Snapshot
    :members:

.. autoclass:: abgleich.Transaction
    :members:

.. autoclass:: abgleich.TransactionList
    :members:

.. autoclass:: abgleich.TransactionMeta
    :members:

.. autoclass:: abgleich.Zpool
    :members:
